@@ -1,5 +1,11 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * netlink-private/tc.h		Local Traffic Control Interface
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2003-2013 Thomas Graf <tgraf@suug.ch>
  */
 
