@@ -1,10 +1,14 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * src/lib/bfifo.c     	bfifo module for CLI lib
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2010-2011 Thomas Graf <tgraf@suug.ch>
  */
 
-#include "nl-default.h"
-
 #include <netlink/cli/utils.h>
 #include <netlink/cli/tc.h>
 #include <netlink/route/qdisc/fifo.h>
@@ -68,12 +72,12 @@ static struct nl_cli_tc_module bfifo_module =
 	.tm_parse_argv		= bfifo_parse_argv,
 };
 
-static void _nl_init bfifo_init(void)
+static void __init bfifo_init(void)
 {
 	nl_cli_tc_register(&bfifo_module);
 }
 
-static void _nl_exit bfifo_exit(void)
+static void __exit bfifo_exit(void)
 {
 	nl_cli_tc_unregister(&bfifo_module);
 }
