@@ -1,5 +1,12 @@
 /* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * lib/genl/mngt.c		Generic Netlink Management
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2003-2012 Thomas Graf <tgraf@suug.ch>
  */
 
@@ -12,8 +19,7 @@
  * @{
  */
 
-#include "nl-default.h"
-
+#include <netlink-private/genl.h>
 #include <netlink/netlink.h>
 #include <netlink/genl/genl.h>
 #include <netlink/genl/mngt.h>
@@ -21,7 +27,7 @@
 #include <netlink/genl/ctrl.h>
 #include <netlink/utils.h>
 
-#include "nl-genl.h"
+#include "netlink-private/utils.h"
 
 /** @cond SKIP */
 
@@ -127,13 +133,13 @@ char *genl_op2name(int family, int op, char *buf, size_t len)
 			cmd = &ops->o_cmds[i];
 
 			if (cmd->c_id == op) {
-				_nl_strncpy_trunc(buf, cmd->c_name, len);
+				strncpy(buf, cmd->c_name, len - 1);
 				return buf;
 			}
 		}
 	}
 
-	_nl_strncpy_trunc(buf, "unknown", len);
+	strncpy(buf, "unknown", len - 1);
 	return NULL;
 }
 
@@ -248,7 +254,7 @@ int genl_register(struct nl_cache_ops *ops)
 		goto errout;
 	}
 
-	if (ops->co_hdrsize < (int)GENL_HDRSIZE(0)) {
+	if (ops->co_hdrsize < GENL_HDRSIZE(0)) {
 		err = -NLE_INVAL;
 		goto errout;
 	}
@@ -308,7 +314,6 @@ static int __genl_ops_resolve(struct nl_cache *ctrl, struct genl_ops *ops)
 	return -NLE_OBJ_NOTFOUND;
 }
 
-/* WARNING: this symbol is wrongly exported in libnl-genl-3.sym. */
 int genl_resolve_id(struct genl_ops *ops)
 {
 	struct nl_sock *sk;
