@@ -1,8 +1,12 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * lib/route/link/geneve.c      Geneve Link Info
+ *         This library is free software; you can redistribute it and/or
+ *         modify it under the terms of the GNU Lesser General Public
+ *         License as published by the Free Software Foundation version 2.1
+ *         of the License.
+ *
  * Copyright (c) 2018 Wang Jian <jianjian.wang1@gmail.com>
  */
-
 /**
  * @ingroup link
  * @defgroup geneve Geneve
@@ -15,16 +19,14 @@
  *
  * @{
  */
-#include "nl-default.h"
-
+#include <netlink-private/netlink.h>
 #include <netlink/netlink.h>
 #include <netlink/utils.h>
 #include <netlink/object.h>
 #include <netlink/route/rtnl.h>
+#include <netlink-private/route/link/api.h>
 #include <netlink/route/link/geneve.h>
 
-#include "nl-route.h"
-#include "link-api.h"
 
 /** @cond SKIP */
 #define GENEVE_ATTR_ID          (1<<0)
@@ -188,12 +190,16 @@ static void geneve_dump_details(struct rtnl_link *link, struct nl_dump_params *p
 
         if (geneve->mask & GENEVE_ATTR_REMOTE) {
                 nl_dump(p, "     remote ");
-                nl_dump_line(p, "%s\n",
-                             _nl_inet_ntop(AF_INET, &geneve->remote, addr));
+                if (inet_ntop(AF_INET, &geneve->remote, addr, sizeof(addr)))
+                        nl_dump_line(p, "%s\n", addr);
+                else
+                        nl_dump_line(p, "%#x\n", ntohs(geneve->remote));
         } else if (geneve->mask & GENEVE_ATTR_REMOTE6) {
                 nl_dump(p, "      remote ");
-                nl_dump_line(p, "%s\n",
-                             _nl_inet_ntop(AF_INET6, &geneve->remote6, addr));
+                if (inet_ntop(AF_INET6, &geneve->remote6, addr, sizeof(addr)))
+                        nl_dump_line(p, "%s\n", addr);
+                else
+                        nl_dump_line(p, "%#x\n", geneve->remote6);
         }
 
         if (geneve->mask & GENEVE_ATTR_TTL) {
@@ -234,7 +240,7 @@ static void geneve_dump_details(struct rtnl_link *link, struct nl_dump_params *p
 
         if (geneve->mask & GENEVE_ATTR_UDP_ZERO_CSUM6_RX) {
                 nl_dump(p, "      udp-zero-csum6-rx ");
-                if (geneve->udp_zero_csum6_rx)
+                if (geneve->udp_zero_csum6_tx)
                         nl_dump_line(p, "enabled (%#x)\n", geneve->udp_zero_csum6_rx);
                 else
                         nl_dump_line(p, "disabled\n");
@@ -350,11 +356,12 @@ static struct rtnl_link_info_ops geneve_info_ops = {
 struct rtnl_link *rtnl_link_geneve_alloc(void)
 {
         struct rtnl_link *link;
+        int err;
 
         if (!(link = rtnl_link_alloc()))
                 return NULL;
 
-        if (rtnl_link_set_type(link, "geneve") < 0) {
+        if ((err = rtnl_link_set_type(link, "geneve")) < 0) {
                 rtnl_link_put(link);
                 return NULL;
         }
@@ -790,12 +797,12 @@ int rtnl_link_geneve_get_flags(struct rtnl_link *link, uint8_t *flags)
 }
 
 /** @} */
-static void _nl_init geneve_init(void)
+static void __init geneve_init(void)
 {
         rtnl_link_register_info(&geneve_info_ops);
 }
 
-static void _nl_exit geneve_exit(void)
+static void __exit geneve_exit(void)
 {
         rtnl_link_unregister_info(&geneve_info_ops);
 }
