@@ -1,5 +1,11 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * lib/route/link/ppp.c		PPP Link Module
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2016 Jonas Johansson <jonasj76@gmail.com>
  */
 
@@ -14,13 +20,11 @@
  * @{
  */
 
-#include "nl-default.h"
-
 #include <netlink/route/link/ppp.h>
-#include <netlink/netlink.h>
 
-#include "nl-route.h"
-#include "link-api.h"
+#include <netlink-private/netlink.h>
+#include <netlink/netlink.h>
+#include <netlink-private/route/link/api.h>
 
 /** @cond SKIP */
 #define PPP_ATTR_FD		(1<<0)
@@ -152,11 +156,12 @@ static struct rtnl_link_info_ops ppp_info_ops = {
 struct rtnl_link *rtnl_link_ppp_alloc(void)
 {
 	struct rtnl_link *link;
+	int err;
 
 	if (!(link = rtnl_link_alloc()))
 		return NULL;
 
-	if (rtnl_link_set_type(link, "ppp") < 0) {
+	if ((err = rtnl_link_set_type(link, "ppp")) < 0) {
 		rtnl_link_put(link);
 		return NULL;
 	}
@@ -206,12 +211,12 @@ int rtnl_link_ppp_get_fd(struct rtnl_link *link, int32_t *fd)
 
 /** @} */
 
-static void _nl_init ppp_init(void)
+static void __init ppp_init(void)
 {
 	rtnl_link_register_info(&ppp_info_ops);
 }
 
-static void _nl_exit ppp_exit(void)
+static void __exit ppp_exit(void)
 {
 	rtnl_link_unregister_info(&ppp_info_ops);
 }
