@@ -39,9 +39,7 @@
  * @brief
  */
 
-#include "nl-default.h"
-
-#include <time.h>
+#include <netlink-private/netlink.h>
 #include <netlink/netlink.h>
 #include <netlink/cache.h>
 #include <netlink/object.h>
@@ -50,39 +48,6 @@
 #include <netlink/xfrm/template.h>
 #include <netlink/xfrm/sp.h>
 
-#include "nl-xfrm.h"
-#include "nl-priv-dynamic-core/object-api.h"
-#include "nl-priv-dynamic-core/nl-core.h"
-#include "nl-priv-dynamic-core/cache-api.h"
-#include "nl-aux-core/nl-core.h"
-#include "nl-aux-xfrm/nl-xfrm.h"
-
-struct xfrmnl_userpolicy_type {
-	uint8_t                         type;
-	uint16_t                        reserved1;
-	uint16_t                        reserved2;
-};
-
-struct xfrmnl_sp {
-	NLHDR_COMMON
-
-	struct xfrmnl_sel*              sel;
-	struct xfrmnl_ltime_cfg*        lft;
-	struct xfrmnl_lifetime_cur      curlft;
-	uint32_t                        priority;
-	uint32_t                        index;
-	uint8_t                         dir;
-	uint8_t                         action;
-	uint8_t                         flags;
-	uint8_t                         share;
-	struct xfrmnl_user_sec_ctx*     sec_ctx;
-	struct xfrmnl_userpolicy_type   uptype;
-	uint32_t                        nr_user_tmpl;
-	struct nl_list_head             usertmpl_list;
-	struct xfrmnl_mark              mark;
-	uint32_t                        if_id;
-};
-
 /** @cond SKIP */
 #define XFRM_SP_ATTR_SEL            0x01
 #define XFRM_SP_ATTR_LTIME_CFG      0x02
@@ -97,7 +62,6 @@ struct xfrmnl_sp {
 #define XFRM_SP_ATTR_SECCTX         0x400
 #define XFRM_SP_ATTR_TMPL           0x800
 #define XFRM_SP_ATTR_MARK           0x1000
-#define XFRM_SP_ATTR_IF_ID          0x2000
 
 static struct nl_cache_ops  xfrmnl_sp_ops;
 static struct nl_object_ops xfrm_sp_obj_ops;
@@ -129,8 +93,9 @@ static void xfrm_sp_free_data(struct nl_object *c)
 	xfrmnl_sel_put (sp->sel);
 	xfrmnl_ltime_cfg_put (sp->lft);
 
-	if (sp->sec_ctx) {
-		free(sp->sec_ctx);
+	if(sp->sec_ctx)
+	{
+		free (sp->sec_ctx);
 	}
 
 	nl_list_for_each_entry_safe(utmpl, tmp, &sp->usertmpl_list, utmpl_list) {
@@ -141,38 +106,33 @@ static void xfrm_sp_free_data(struct nl_object *c)
 
 static int xfrm_sp_clone(struct nl_object *_dst, struct nl_object *_src)
 {
-	struct xfrmnl_sp*        dst = nl_object_priv(_dst);
-	struct xfrmnl_sp*        src = nl_object_priv(_src);
-	struct xfrmnl_user_tmpl *utmpl;
-	struct xfrmnl_user_tmpl *new;
+	struct xfrmnl_sp*       dst = nl_object_priv(_dst);
+	struct xfrmnl_sp*       src = nl_object_priv(_src);
+	uint32_t                len = 0;
+	struct xfrmnl_user_tmpl *utmpl, *new;
 
-	dst->sel = NULL;
-	dst->lft = NULL;
-	dst->sec_ctx = NULL;
-	nl_init_list_head(&dst->usertmpl_list);
-
-	if (src->sel) {
+	if (src->sel)
 		if ((dst->sel = xfrmnl_sel_clone (src->sel)) == NULL)
 			return -NLE_NOMEM;
-	}
 
-	if (src->lft) {
+	if (src->lft)
 		if ((dst->lft = xfrmnl_ltime_cfg_clone (src->lft)) == NULL)
 			return -NLE_NOMEM;
-	}
 
-	if (src->sec_ctx) {
-		uint32_t len =   sizeof (struct xfrmnl_user_sec_ctx) + src->sec_ctx->ctx_len;
-
-		if ((dst->sec_ctx = malloc (len)) == NULL)
+	if(src->sec_ctx)
+	{
+		len =   sizeof (struct xfrmnl_user_sec_ctx) + src->sec_ctx->ctx_len;
+		if ((dst->sec_ctx = calloc (1, len)) == NULL)
 			return -NLE_NOMEM;
-		memcpy(dst->sec_ctx, src->sec_ctx, len);
+		memcpy ((void *)dst->sec_ctx, (void *)src->sec_ctx, len);
 	}
 
+	nl_init_list_head(&dst->usertmpl_list);
 	nl_list_for_each_entry(utmpl, &src->usertmpl_list, utmpl_list) {
 		new = xfrmnl_user_tmpl_clone (utmpl);
 		if (!new)
 			return -NLE_NOMEM;
+
 		xfrmnl_sp_add_usertemplate(dst, new);
 	}
 
@@ -187,34 +147,31 @@ static uint64_t xfrm_sp_compare(struct nl_object *_a, struct nl_object *_b,
 	struct xfrmnl_user_tmpl *tmpl_a, *tmpl_b;
 	uint64_t diff = 0;
 
-#define _DIFF(ATTR, EXPR) ATTR_DIFF(attrs, ATTR, a, b, EXPR)
-	diff |= _DIFF(XFRM_SP_ATTR_SEL, xfrmnl_sel_cmp(a->sel, b->sel));
-	diff |= _DIFF(XFRM_SP_ATTR_LTIME_CFG,
-		      xfrmnl_ltime_cfg_cmp(a->lft, b->lft));
-	diff |= _DIFF(XFRM_SP_ATTR_PRIO, a->priority != b->priority);
-	diff |= _DIFF(XFRM_SP_ATTR_INDEX, a->index != b->index);
-	diff |= _DIFF(XFRM_SP_ATTR_DIR, a->dir != b->dir);
-	diff |= _DIFF(XFRM_SP_ATTR_ACTION, a->action != b->action);
-	diff |= _DIFF(XFRM_SP_ATTR_FLAGS, a->flags != b->flags);
-	diff |= _DIFF(XFRM_SP_ATTR_SHARE, a->share != b->share);
-	diff |= _DIFF(XFRM_SP_ATTR_SECCTX,
-		      ((a->sec_ctx->len != b->sec_ctx->len) ||
-		       (a->sec_ctx->exttype != b->sec_ctx->exttype) ||
-		       (a->sec_ctx->ctx_alg != b->sec_ctx->ctx_alg) ||
-		       (a->sec_ctx->ctx_doi != b->sec_ctx->ctx_doi) ||
-		       (a->sec_ctx->ctx_len != b->sec_ctx->ctx_len) ||
-		       strcmp(a->sec_ctx->ctx, b->sec_ctx->ctx)));
-	diff |= _DIFF(XFRM_SP_ATTR_POLTYPE, (a->uptype.type != b->uptype.type));
-	diff |= _DIFF(XFRM_SP_ATTR_TMPL, (a->nr_user_tmpl != b->nr_user_tmpl));
-	diff |= _DIFF(XFRM_SP_ATTR_MARK,
-		      (a->mark.m != b->mark.m) || (a->mark.v != b->mark.v));
-	diff |= _DIFF(XFRM_SP_ATTR_IF_ID, a->if_id != b->if_id);
+#define XFRM_SP_DIFF(ATTR, EXPR) ATTR_DIFF(attrs, XFRM_SP_ATTR_##ATTR, a, b, EXPR)
+	diff |= XFRM_SP_DIFF(SEL,	xfrmnl_sel_cmp(a->sel, b->sel));
+	diff |= XFRM_SP_DIFF(LTIME_CFG,	xfrmnl_ltime_cfg_cmp(a->lft, b->lft));
+	diff |= XFRM_SP_DIFF(PRIO,	a->priority != b->priority);
+	diff |= XFRM_SP_DIFF(INDEX,	a->index != b->index);
+	diff |= XFRM_SP_DIFF(DIR,	a->dir != b->dir);
+	diff |= XFRM_SP_DIFF(ACTION,	a->action != b->action);
+	diff |= XFRM_SP_DIFF(FLAGS,	a->flags != b->flags);
+	diff |= XFRM_SP_DIFF(SHARE,	a->share != b->share);
+	diff |= XFRM_SP_DIFF(SECCTX,((a->sec_ctx->len != b->sec_ctx->len) ||
+	                            (a->sec_ctx->exttype != b->sec_ctx->exttype) ||
+	                            (a->sec_ctx->ctx_alg != b->sec_ctx->ctx_alg) ||
+	                            (a->sec_ctx->ctx_doi != b->sec_ctx->ctx_doi) ||
+	                            (a->sec_ctx->ctx_len != b->sec_ctx->ctx_len) ||
+	                            strcmp(a->sec_ctx->ctx, b->sec_ctx->ctx)));
+	diff |= XFRM_SP_DIFF(POLTYPE,(a->uptype.type != b->uptype.type));
+	diff |= XFRM_SP_DIFF(TMPL,(a->nr_user_tmpl != b->nr_user_tmpl));
+	diff |= XFRM_SP_DIFF(MARK,(a->mark.m != b->mark.m) ||
+	                          (a->mark.v != b->mark.v));
 
 	/* Compare the templates */
 	nl_list_for_each_entry(tmpl_b, &b->usertmpl_list, utmpl_list)
 	nl_list_for_each_entry(tmpl_a, &a->usertmpl_list, utmpl_list)
 	diff |= xfrmnl_user_tmpl_cmp (tmpl_a, tmpl_b);
-#undef _DIFF
+#undef XFRM_SP_DIFF
 
 	return diff;
 }
@@ -237,7 +194,6 @@ static const struct trans_tbl sp_attrs[] = {
 	__ADD(XFRM_SP_ATTR_SECCTX, security_context),
 	__ADD(XFRM_SP_ATTR_TMPL, user_template),
 	__ADD(XFRM_SP_ATTR_MARK, mark),
-	__ADD(XFRM_SP_ATTR_IF_ID, if_id),
 };
 
 static char* xfrm_sp_attrs2str(int attrs, char *buf, size_t len)
@@ -364,7 +320,6 @@ static void xfrm_sp_dump_line(struct nl_object *a, struct nl_dump_params *p)
 	char                dst[INET6_ADDRSTRLEN+5], src[INET6_ADDRSTRLEN+5];
 	time_t              add_time, use_time;
 	struct tm           *add_time_tm, *use_time_tm;
-	struct tm           tm_buf;
 
 	nl_addr2str(xfrmnl_sel_get_saddr (sp->sel), src, sizeof(src));
 	nl_addr2str (xfrmnl_sel_get_daddr (sp->sel), dst, sizeof (dst));
@@ -402,30 +357,20 @@ static void xfrm_sp_dump_line(struct nl_object *a, struct nl_dump_params *p)
 		sprintf (share, "INF");
 	else
 		sprintf (share, "%" PRIu64, sp->lft->hard_packet_limit);
-	nl_dump_line(p, "\t\tsoft limit: %s (bytes), %s (packets) \n", dir,
-		     action);
-	nl_dump_line(p, "\t\thard limit: %s (bytes), %s (packets) \n", flags,
-		     share);
-	nl_dump_line(
-		p,
-		"\t\tsoft add_time: %llu (seconds), soft use_time: %llu (seconds) \n",
-		(long long unsigned)sp->lft->soft_add_expires_seconds,
-		(long long unsigned)sp->lft->soft_use_expires_seconds);
-	nl_dump_line(
-		p,
-		"\t\thard add_time: %llu (seconds), hard use_time: %llu (seconds) \n",
-		(long long unsigned)sp->lft->hard_add_expires_seconds,
-		(long long unsigned)sp->lft->hard_use_expires_seconds);
+	nl_dump_line(p, "\t\tsoft limit: %s (bytes), %s (packets) \n", dir, action);
+	nl_dump_line(p, "\t\thard limit: %s (bytes), %s (packets) \n", flags, share);
+	nl_dump_line(p, "\t\tsoft add_time: %llu (seconds), soft use_time: %llu (seconds) \n",
+	             sp->lft->soft_add_expires_seconds, sp->lft->soft_use_expires_seconds);
+	nl_dump_line(p, "\t\thard add_time: %llu (seconds), hard use_time: %llu (seconds) \n",
+	             sp->lft->hard_add_expires_seconds, sp->lft->hard_use_expires_seconds);
 
 	nl_dump_line(p, "\tlifetime current: \n");
-	nl_dump_line(p, "\t\t%llu bytes, %llu packets\n",
-		     (long long unsigned)sp->curlft.bytes,
-		     (long long unsigned)sp->curlft.packets);
+	nl_dump_line(p, "\t\t%llu bytes, %llu packets\n", sp->curlft.bytes, sp->curlft.packets);
 
 	if (sp->curlft.add_time != 0)
 	{
 		add_time = sp->curlft.add_time;
-		add_time_tm = gmtime_r (&add_time, &tm_buf);
+		add_time_tm = gmtime (&add_time);
 		strftime (dst, INET6_ADDRSTRLEN+5, "%Y-%m-%d %H-%M-%S", add_time_tm);
 	}
 	else
@@ -436,7 +381,7 @@ static void xfrm_sp_dump_line(struct nl_object *a, struct nl_dump_params *p)
 	if (sp->curlft.use_time != 0)
 	{
 		use_time = sp->curlft.use_time;
-		use_time_tm = gmtime_r (&use_time, &tm_buf);
+		use_time_tm = gmtime (&use_time);
 		strftime (src, INET6_ADDRSTRLEN+5, "%Y-%m-%d %H-%M-%S", use_time_tm);
 	}
 	else
@@ -471,10 +416,6 @@ static void xfrm_sp_dump_line(struct nl_object *a, struct nl_dump_params *p)
 	if (sp->ce_mask & XFRM_SP_ATTR_MARK)
 		nl_dump_line(p, "\tMark mask: 0x%x Mark value: 0x%x\n", sp->mark.m, sp->mark.v);
 
-
-	if (sp->ce_mask & XFRM_SP_ATTR_IF_ID)
-		nl_dump_line(p, "\tXFRM interface ID: 0x%x\n", sp->if_id);
-
 	nl_dump(p, "\n");
 }
 
@@ -563,47 +504,62 @@ static struct nla_policy xfrm_sp_policy[XFRMA_MAX+1] = {
 	[XFRMA_TMPL]            = { .minlen = sizeof(struct xfrm_user_tmpl) },
 	[XFRMA_POLICY_TYPE]     = { .minlen = sizeof(struct xfrm_userpolicy_type)},
 	[XFRMA_MARK]            = { .minlen = sizeof(struct xfrm_mark) },
-	[XFRMA_IF_ID]           = { .type = NLA_U32 },
 };
 
 static int xfrm_sp_request_update(struct nl_cache *c, struct nl_sock *h)
 {
-	return nl_send_simple (h, XFRM_MSG_GETPOLICY, NLM_F_DUMP, NULL, 0);
+	struct xfrm_userpolicy_id sp_id;
+
+	memset (&sp_id, 0, sizeof (sp_id));
+	return nl_send_simple (h, XFRM_MSG_GETPOLICY, NLM_F_DUMP,
+	                       &sp_id, sizeof (sp_id));
 }
 
 int xfrmnl_sp_parse(struct nlmsghdr *n, struct xfrmnl_sp **result)
 {
-	_nl_auto_nl_addr struct nl_addr *addr1 = NULL;
-	_nl_auto_nl_addr struct nl_addr *addr2 = NULL;
-	_nl_auto_xfrmnl_sp struct xfrmnl_sp *sp = NULL;
+	struct xfrmnl_sp                *sp;
 	struct nlattr                   *tb[XFRMA_MAX + 1];
 	struct xfrm_userpolicy_info     *sp_info;
 	int                             len, err;
+	struct nl_addr*                 addr;
 
 	sp = xfrmnl_sp_alloc();
-	if (!sp)
-		return -NLE_NOMEM;
+	if (!sp) {
+		err = -NLE_NOMEM;
+		goto errout;
+	}
 
 	sp->ce_msgtype = n->nlmsg_type;
 	if (n->nlmsg_type == XFRM_MSG_DELPOLICY)
+	{
 		sp_info = (struct xfrm_userpolicy_info*)((char *)nlmsg_data(n) + sizeof (struct xfrm_userpolicy_id) + NLA_HDRLEN);
+	}
 	else
+	{
 		sp_info = nlmsg_data(n);
+	}
 
 	err = nlmsg_parse(n, sizeof(struct xfrm_userpolicy_info), tb, XFRMA_MAX, xfrm_sp_policy);
 	if (err < 0)
-		return err;
+	{
+		printf ("parse error: %d \n", err);
+		goto errout;
+	}
 
-	if (!(addr1 = _nl_addr_build(sp_info->sel.family, &sp_info->sel.daddr)))
-		return -NLE_NOMEM;
-	nl_addr_set_prefixlen (addr1, sp_info->sel.prefixlen_d);
-	xfrmnl_sel_set_daddr (sp->sel, addr1);
+	if (sp_info->sel.family == AF_INET)
+		addr    = nl_addr_build (sp_info->sel.family, &sp_info->sel.daddr.a4, sizeof (sp_info->sel.daddr.a4));
+	else
+		addr    = nl_addr_build (sp_info->sel.family, &sp_info->sel.daddr.a6, sizeof (sp_info->sel.daddr.a6));
+	nl_addr_set_prefixlen (addr, sp_info->sel.prefixlen_d);
+	xfrmnl_sel_set_daddr (sp->sel, addr);
 	xfrmnl_sel_set_prefixlen_d (sp->sel, sp_info->sel.prefixlen_d);
 
-	if (!(addr2 = _nl_addr_build(sp_info->sel.family, &sp_info->sel.saddr)))
-		return -NLE_NOMEM;
-	nl_addr_set_prefixlen (addr2, sp_info->sel.prefixlen_s);
-	xfrmnl_sel_set_saddr (sp->sel, addr2);
+	if (sp_info->sel.family == AF_INET)
+		addr    = nl_addr_build (sp_info->sel.family, &sp_info->sel.saddr.a4, sizeof (sp_info->sel.saddr.a4));
+	else
+		addr    = nl_addr_build (sp_info->sel.family, &sp_info->sel.saddr.a6, sizeof (sp_info->sel.saddr.a6));
+	nl_addr_set_prefixlen (addr, sp_info->sel.prefixlen_s);
+	xfrmnl_sel_set_saddr (sp->sel, addr);
 	xfrmnl_sel_set_prefixlen_s (sp->sel, sp_info->sel.prefixlen_s);
 
 	xfrmnl_sel_set_dport (sp->sel, ntohs (sp_info->sel.dport));
@@ -644,45 +600,51 @@ int xfrmnl_sp_parse(struct nlmsghdr *n, struct xfrmnl_sp **result)
 
 	if (tb[XFRMA_SEC_CTX]) {
 		struct xfrm_user_sec_ctx* ctx = nla_data(tb[XFRMA_SEC_CTX]);
-
 		len = sizeof (struct xfrmnl_user_sec_ctx) + ctx->ctx_len;
 		if ((sp->sec_ctx = calloc (1, len)) == NULL)
-			return -NLE_NOMEM;
+		{
+			err = -NLE_NOMEM;
+			goto errout;
+		}
 		memcpy ((void *)sp->sec_ctx, (void *)ctx, len);
 		sp->ce_mask     |= XFRM_SP_ATTR_SECCTX;
 	}
 
 	if (tb[XFRMA_POLICY_TYPE]) {
 		struct xfrm_userpolicy_type* up = nla_data(tb[XFRMA_POLICY_TYPE]);
-
 		memcpy ((void *)&sp->uptype, (void *)up, sizeof (struct xfrm_userpolicy_type));
 		sp->ce_mask     |= XFRM_SP_ATTR_POLTYPE;
 	}
 
 	if (tb[XFRMA_TMPL]) {
 		struct xfrm_user_tmpl*      tmpl = nla_data(tb[XFRMA_TMPL]);
+		struct xfrmnl_user_tmpl*    sputmpl;
 		uint32_t                    i;
 		uint32_t                    num_tmpls = nla_len(tb[XFRMA_TMPL]) / sizeof (*tmpl);
+		struct  nl_addr*            addr;
 
 		for (i = 0; (i < num_tmpls) && (tmpl); i ++, tmpl++)
 		{
-			_nl_auto_xfrmnl_user_tmpl struct xfrmnl_user_tmpl *sputmpl = NULL;
-			_nl_auto_nl_addr struct nl_addr *addr1 = NULL;
-			_nl_auto_nl_addr struct nl_addr *addr2 = NULL;
-
 			if ((sputmpl = xfrmnl_user_tmpl_alloc ()) == NULL)
-				return -NLE_NOMEM;
+			{
+				err = -NLE_NOMEM;
+				goto errout;
+			}
 
-			if (!(addr1 = _nl_addr_build(tmpl->family, &tmpl->id.daddr)))
-				return -NLE_NOMEM;
-			xfrmnl_user_tmpl_set_daddr (sputmpl, addr1);
+			if (tmpl->family == AF_INET)
+				addr = nl_addr_build(tmpl->family, &tmpl->id.daddr.a4, sizeof (tmpl->id.daddr.a4));
+			else
+				addr = nl_addr_build(tmpl->family, &tmpl->id.daddr.a6, sizeof (tmpl->id.daddr.a6));
+			xfrmnl_user_tmpl_set_daddr (sputmpl, addr);
 			xfrmnl_user_tmpl_set_spi (sputmpl, ntohl(tmpl->id.spi));
 			xfrmnl_user_tmpl_set_proto (sputmpl, tmpl->id.proto);
 			xfrmnl_user_tmpl_set_family (sputmpl, tmpl->family);
 
-			if (!(addr2 = _nl_addr_build(tmpl->family, &tmpl->saddr)))
-				return -NLE_NOMEM;
-			xfrmnl_user_tmpl_set_saddr (sputmpl, addr2);
+			if (tmpl->family == AF_INET)
+				addr = nl_addr_build(tmpl->family, &tmpl->saddr.a4, sizeof (tmpl->saddr.a4));
+			else
+				addr = nl_addr_build(tmpl->family, &tmpl->saddr.a6, sizeof (tmpl->saddr.a6));
+			xfrmnl_user_tmpl_set_saddr (sputmpl, addr);
 
 			xfrmnl_user_tmpl_set_reqid (sputmpl, tmpl->reqid);
 			xfrmnl_user_tmpl_set_mode (sputmpl, tmpl->mode);
@@ -691,7 +653,7 @@ int xfrmnl_sp_parse(struct nlmsghdr *n, struct xfrmnl_sp **result)
 			xfrmnl_user_tmpl_set_aalgos (sputmpl, tmpl->aalgos);
 			xfrmnl_user_tmpl_set_ealgos (sputmpl, tmpl->ealgos);
 			xfrmnl_user_tmpl_set_calgos (sputmpl, tmpl->calgos);
-			xfrmnl_sp_add_usertemplate (sp, _nl_steal_pointer(&sputmpl));
+			xfrmnl_sp_add_usertemplate (sp, sputmpl);
 
 			sp->ce_mask     |=  XFRM_SP_ATTR_TMPL;
 		}
@@ -704,13 +666,12 @@ int xfrmnl_sp_parse(struct nlmsghdr *n, struct xfrmnl_sp **result)
 		sp->ce_mask |= XFRM_SP_ATTR_MARK;
 	}
 
-	if (tb[XFRMA_IF_ID]) {
-		sp->if_id = nla_get_u32(tb[XFRMA_IF_ID]);
-		sp->ce_mask |= XFRM_SP_ATTR_IF_ID;
-	}
-
-	*result = _nl_steal_pointer(&sp);
+	*result = sp;
 	return 0;
+
+errout:
+	xfrmnl_sp_put(sp);
+	return err;
 }
 
 static int xfrm_sp_msg_parser(struct nl_cache_ops *ops, struct sockaddr_nl *who,
@@ -916,10 +877,6 @@ static int build_xfrm_sp_message(struct xfrmnl_sp *tmpl, int cmd, int flags, str
 		NLA_PUT (msg, XFRMA_MARK, sizeof (struct xfrm_mark), &tmpl->mark);
 	}
 
-	if (tmpl->ce_mask & XFRM_SP_ATTR_IF_ID) {
-		NLA_PUT_U32 (msg, XFRMA_IF_ID, tmpl->if_id);
-	}
-
 	*result = msg;
 	return 0;
 
@@ -1047,10 +1004,6 @@ static int build_xfrm_sp_delete_message(struct xfrmnl_sp *tmpl, int cmd, int fla
 		NLA_PUT (msg, XFRMA_MARK, len, &tmpl->mark);
 	}
 
-	if (tmpl->ce_mask & XFRM_SP_ATTR_IF_ID) {
-		NLA_PUT_U32 (msg, XFRMA_IF_ID, tmpl->if_id);
-	}
-
 	*result = msg;
 	return 0;
 
@@ -1137,16 +1090,16 @@ int xfrmnl_sp_set_lifetime_cfg (struct xfrmnl_sp* sp, struct xfrmnl_ltime_cfg* l
 	return 0;
 }
 
-int xfrmnl_sp_get_curlifetime (struct xfrmnl_sp* sp, unsigned long long int* curr_bytes,
+int xfrmnl_sp_get_curlifetime (struct xfrmnl_sp* sa, unsigned long long int* curr_bytes,
                                unsigned long long int* curr_packets, unsigned long long int* curr_add_time, unsigned long long int* curr_use_time)
 {
-	if (sp == NULL || curr_bytes == NULL || curr_packets == NULL || curr_add_time == NULL || curr_use_time == NULL)
+	if (sa == NULL || curr_bytes == NULL || curr_packets == NULL || curr_add_time == NULL || curr_use_time == NULL)
 		return -1;
 
-	*curr_bytes     =   sp->curlft.bytes;
-	*curr_packets   =   sp->curlft.packets;
-	*curr_add_time  =   sp->curlft.add_time;
-	*curr_use_time  =   sp->curlft.use_time;
+	*curr_bytes     =   sa->curlft.bytes;
+	*curr_packets   =   sa->curlft.packets;
+	*curr_add_time  =   sa->curlft.add_time;
+	*curr_use_time  =   sa->curlft.use_time;
 
 	return 0;
 }
@@ -1303,7 +1256,7 @@ int xfrmnl_sp_get_sec_ctx (struct xfrmnl_sp* sp, unsigned int* len, unsigned int
  *
  * @return     0 if sucessfull, else -1
  */
-int xfrmnl_sp_set_sec_ctx (struct xfrmnl_sp* sp, unsigned int len, unsigned int exttype, unsigned int alg, unsigned int doi, unsigned int ctx_len, char* ctx_str)
+int xfrmnl_sp_set_sec_ctx (struct xfrmnl_sp* sp, unsigned int len __attribute__((unused)), unsigned int exttype, unsigned int alg, unsigned int doi, unsigned int ctx_len, char* ctx_str)
 {
 	/* Free up the old context string and allocate new one */
 	if (sp->sec_ctx)
@@ -1353,8 +1306,6 @@ void xfrmnl_sp_remove_usertemplate(struct xfrmnl_sp *sp, struct xfrmnl_user_tmpl
 	if (sp->ce_mask & XFRM_SP_ATTR_TMPL) {
 		sp->nr_user_tmpl--;
 		nl_list_del(&utmpl->utmpl_list);
-		if (sp->nr_user_tmpl == 0)
-			sp->ce_mask &= ~XFRM_SP_ATTR_TMPL;
 	}
 }
 
@@ -1390,15 +1341,12 @@ void xfrmnl_sp_foreach_usertemplate(struct xfrmnl_sp *r,
 struct xfrmnl_user_tmpl *xfrmnl_sp_usertemplate_n(struct xfrmnl_sp *r, int n)
 {
 	struct xfrmnl_user_tmpl *utmpl;
+	uint32_t i;
 
-	if (r->ce_mask & XFRM_SP_ATTR_TMPL && n >= 0 &&
-	    ((unsigned)n) < r->nr_user_tmpl) {
-		uint32_t i;
-
+	if (r->ce_mask & XFRM_SP_ATTR_TMPL && r->nr_user_tmpl > n) {
 		i = 0;
 		nl_list_for_each_entry(utmpl, &r->usertmpl_list, utmpl_list) {
-			if (i == ((unsigned)n))
-				return utmpl;
+			if (i == n) return utmpl;
 			i++;
 		}
 	}
@@ -1430,27 +1378,6 @@ int xfrmnl_sp_set_mark (struct xfrmnl_sp* sp, unsigned int value, unsigned int m
 	return 0;
 }
 
-int xfrmnl_sp_get_if_id (struct xfrmnl_sp* sp, uint32_t* if_id)
-{
-	if (if_id == NULL)
-		return -NLE_INVAL;
-
-	if (!(sp->ce_mask & XFRM_SP_ATTR_IF_ID))
-		return -NLE_NOATTR;
-
-	*if_id = sp->if_id;
-
-	return 0;
-}
-
-int xfrmnl_sp_set_if_id (struct xfrmnl_sp* sp, uint32_t if_id)
-{
-	sp->if_id = if_id;
-	sp->ce_mask |= XFRM_SP_ATTR_IF_ID;
-
-	return 0;
-}
-
 /** @} */
 
 static struct nl_object_ops xfrm_sp_obj_ops = {
@@ -1496,12 +1423,12 @@ static struct nl_cache_ops xfrmnl_sp_ops = {
  * @{
  */
 
-static void _nl_init xfrm_sp_init(void)
+static void __attribute__ ((constructor)) xfrm_sp_init(void)
 {
 	nl_cache_mngt_register(&xfrmnl_sp_ops);
 }
 
-static void _nl_exit xfrm_sp_exit(void)
+static void __attribute__ ((destructor)) xfrm_sp_exit(void)
 {
 	nl_cache_mngt_unregister(&xfrmnl_sp_ops);
 }
