@@ -1,5 +1,12 @@
 /* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * src/utils.c		Utilities
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2003-2009 Thomas Graf <tgraf@suug.ch>
  */
 
@@ -15,15 +22,15 @@
  * accordingly via nl_cli_fatal().
  */
 
-#include "nl-default.h"
-
+#include <netlink/cli/utils.h>
 #include <locale.h>
+
+#include "lib/defs.h"
+
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
 #endif
 
-#include <netlink/cli/utils.h>
-
 /**
  * Parse a text based 32 bit unsigned integer argument
  * @arg arg		Integer in text form.
@@ -223,19 +230,16 @@ void nl_cli_load_module(const char *prefix, const char *name)
 	char path[FILENAME_MAX+1];
 
 	snprintf(path, sizeof(path), "%s/%s/%s.so",
-		 _NL_PKGLIBDIR, prefix, name);
+		 PKGLIBDIR, prefix, name);
 
 #ifdef HAVE_DLFCN_H
 	{
 		void *handle;
 
-		handle = dlopen(path, RTLD_NOW);
-		if (!handle) {
+		if (!(handle = dlopen(path, RTLD_NOW))) {
 			nl_cli_fatal(ENOENT, "Unable to load module \"%s\": %s\n",
 			             path, dlerror());
 		}
-		/* We intentionally leak the dlopen handle. */
-		/* coverity[RESOURCE_LEAK] */
 	}
 #else
 	nl_cli_fatal(ENOTSUP, "Unable to load module \"%s\": built without dynamic libraries support\n",
