@@ -1,13 +1,17 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * tests/check-all.c		overall unit test program
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2013 Thomas Graf <tgraf@suug.ch>
  */
 
-#include "nl-default.h"
-
 #include <check.h>
 
-#include "cksuite-all.h"
+#include "util.h"
 
 static Suite *main_suite(void)
 {
@@ -20,16 +24,16 @@ int main(int argc, char *argv[])
 {
 	SRunner *runner;
 	int nfailed;
-
+	
 	runner = srunner_create(main_suite());
 
+	/* Add testsuites below */
+
 	srunner_add_suite(runner, make_nl_addr_suite());
 	srunner_add_suite(runner, make_nl_attr_suite());
 	srunner_add_suite(runner, make_nl_ematch_tree_clone_suite());
-	srunner_add_suite(runner, make_nl_netns_suite());
-	srunner_add_suite(runner, make_nl_ip6_tnl_suite());
-	srunner_add_suite(runner, make_nl_route_nh_suite());
-	srunner_add_suite(runner, make_nl_route_nexthop_suite());
+
+	/* Do not add testsuites below this line */
 
 	srunner_run_all(runner, CK_ENV);
 
