@@ -1,12 +1,7 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
-
-#include "nl-default.h"
-
-#include <linux/genetlink.h>
+#include <netlink/cli/utils.h>
 
 #include <linux/taskstats.h>
-
-#include <netlink/cli/utils.h>
+#include <linux/genetlink.h>
 
 static struct nla_policy attr_policy[TASKSTATS_TYPE_MAX+1] = {
 	[TASKSTATS_TYPE_PID]	= { .type = NLA_U32 },
@@ -67,6 +62,8 @@ static struct genl_cmd cmds[] = {
 	},
 };
 
+#define ARRAY_SIZE(X) (sizeof(X) / sizeof((X)[0]))
+
 static struct genl_ops ops = {
 	.o_name = TASKSTATS_GENL_NAME,
 	.o_cmds = cmds,
